import { Component, OnInit } from '@angular/core';
import { HorseService } from '../../service/horse.service';
import { Horse } from '../../dto/horse';
import { ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-horse',
  templateUrl: './horse.component.html',
  styleUrls: ['./horse.component.scss']
})
export class HorseComponent implements OnInit {

  error = false;
  errorMessage = '';
  horse: Horse;

  constructor(private horseService: HorseService, private route: ActivatedRoute) { }

  ngOnInit(): void {
    // Extract id from url
    const horseId: string = this.route.snapshot.paramMap.get('id');
    this.loadHorse(parseInt(horseId));
  }

  /**
   * Error flag will be deactivated, which clears the error message
   */
  vanishError() {
    this.error = false;
  }

  /**
   * Loads the horse for the specified id
   * @param id the id of the horse
   */
  private loadHorse(id: number) {
    this.horseService.getHorseById(id).subscribe(
      (horse: Horse) => {
        this.horse = horse;
      },
      error => {
        this.defaultServiceErrorHandling(error);
      }
    );
  }

  private defaultServiceErrorHandling(error: any) {
    console.log(error);
    this.error = true;
    if (error.status === 0) {
      // If status is 0, the backend is probably down
      this.errorMessage = 'The backend seems not to be reachable';
    } else if (error.error.message === 'No message available') {
      // If no detailed error message is provided, fall back to the simple error name
      this.errorMessage = error.error.error;
    } else {
      this.errorMessage = error.error.message;
    }
  }
}
